Dojo Button Widget Test

# Dijit Button Test

## Simple, drop down & combo buttons

Buttons can do an action, display a menu, or both:

tooltip on button

## DropDownButtons with different drop down positions

## ComboButtons with different drop down positions

## Buttons with no text label

Buttons have showLabel=false so text is not displayed. If no title attribute supplied, Should have label as title attribute displayed on mouse over

Color
Save
Save
Save As

## Toggle buttons

The button CSS as well as the icon CSS can change on toggle

## Sizing

Short button, tall buttons, big buttons, small buttons... These buttons size to their content (just like <button>).

## Customized buttons

Dojo users can customize styles. Here's an example:

## Toggling the display test

(Ticket #403)

## Programatically changing buttons

clicking the buttons below will change the buttons above

### Button instantiated via javacript:

### DropDownButton instantiated via javacript:

### Submit and Reset Buttons

Testing that submit and reset buttons work properly. OnSubmit and OnReset handlers for the form just output to the console.
Name:

### onClick Tests

Testing that onClick works properly
Value:

### Submit/value test

Submitted name:
Submitted value:

Tests for bubbling: